#
# spec file for package python-flexmock
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flexmock
Version:        0.12.2
Release:        1.3
Summary:        Testing library for creating mocks, stubs and fakes
License:        BSD-2-Clause
URL:            https://github.com/bkabrda/flexmock
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Flexmock is a testing library for Python for creating mocks,
stubs and fakes. The API is inspired by a Ruby library of the same name, but
Python flexmock is not a clone of the Ruby version. It omits a number of
redundancies in the Ruby flexmock API, alters some defaults, and introduces
a number of Python-only features.

%prep
%autosetup -n flexmock-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%{python_sitelib}/flexmock
%{python_sitelib}/flexmock-%{version}-py*.egg-info

%changelog
* Tue Jan 21 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.12.2
  * Fix typing of and_raise (exception instances are allowed).
  * Fix teardown for spying on derived class methods.
  * Remove python 3.6 mentions and add py-version config to pylint.
- Adjust URL to upstream source tarball on Github
* Fri Jul  5 2024 Joshua Smith <smolsheep@opensuse.org>
- Replace deprecated %%setup with %%autosetup
- Fix source URL -- pythonhosted no longer includes setup.py
- Update to 0.12.1:
  * Flexmock Pytest plugin entrypoint missing from setup.py.
- Updates from 0.12.0:
  * Add tox.ini to sdist to make the downstream testing easier.
  * Add Python 3.12 and 3.13 support.
  * Drop Python 3.6 and 3.7 support.
  * Drop Pytest 5.x support.
  * Fixed the pytest integration by switching from wrapping of the
    test runner to the pytest plugin system.
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.3:
  * Add PEP 561 `py.typed` marker file.
  * Re-organize unit tests.
  * Add a warning about the usage of `.new_instances()` method in
    the documentation.
  * Run tests with testtools, subunit, TeamCity, and doctest
    testrunners using tox.
  * Test flexmock API examples using doctest.
  * Re-add Sphinx support for generating man pages.
  * Fix 404 page not loading CSS and Javascript resources in
    documentation.
  * Add Python 3.8, 3.9, 3.10, and 3.11 support.
  * Add type annotations.
  * **BREAKING CHANGE**: Flexmock needs to be imported explicitly
    using `from flexmock import flexmock`.
  * Many error messages have been improved.
  * Drop Python 2.7, 3.4, 3.5 support.
  * Drop Pytest 4.x support.
  * **BREAKING CHANGE**: Removed support for calling `once`,
    `twice`, `never`, and `mock` methods without parentheses.
  * Fix `should_call` is broken if called on a fake object.
  * Fix `and_raise` allows invalid arguments for an exception.
  * Fix AttributeError raised when mocking a proxied object.
  * Fix flexmock not mocking methods properly on derived classes.
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Aug 31 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.10.8:
  * Fix with_args not working built-in functions.
* Wed Aug 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.10.7:
  - Fix ``with_args`` not working built-in functions and methods.
  - Fix previous pytest ``--durations`` fix not working.
- from version 0.10.6
  - Fix flexmock broken with Pytest 4 & 5.
  - Fix new_instances method not working with Python 2.7.
  - Fix multiple expectations for the same classmethod are not matched.
- from version 0.10.5
  - Improve error message on unmatched method signature expectation.
  - Fix using ``should_call`` passes wrong ``runtime_self``.
  - Fix pytest ``--durations`` flag when flexmock is installed.
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.4:
  - drop Python 2.6, 3.3 and Jython support
  - add Python 3.6 and 3.7 support
  - don't hide exception when flexmock is used as context manager
  - fix expectation reset for static methods on pypy 2
  - ensure original exception isn't suppressed in pytest hook
* Tue Mar 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.3:
  - fix compatibility with py.test 4.1
  - minor documentation fixes
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep  7 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Oct 13 2016 alarrosa@suse.com
- Initial package
- Official upstream release 0.10.2
